======================
bisos.bx-bases Scripts
======================

.. contents::
   :depth: 3
..

Overview
========

bpo: python library and scripts (Interactive Command Modules – ICM) are
used to manage abstrations of ByStar Portable Objects.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

   sudo pip install bisos.bpo

Usage
=====

::

   bin/bpoManage.py
